#
# spec file for package ghc-dbus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name dbus
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.9
Release:        1.6
Summary:        A client library for the D-Bus IPC system
License:        Apache-2.0
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-cereal-prof
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-lens-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-th-lift-devel
BuildRequires:  ghc-th-lift-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-xml-conduit-prof
BuildRequires:  ghc-xml-types-devel
BuildRequires:  ghc-xml-types-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-extra-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
D-Bus is a simple, message-based protocol for inter-process communication,
which allows applications to interact with other parts of the machine and the
user's session using remote procedure calls.

D-Bus is a essential part of the modern Linux desktop, where it replaces
earlier protocols such as CORBA and DCOP.

This library is an implementation of the D-Bus protocol in Haskell. It can be
used to add D-Bus support to Haskell applications, without the awkward
interfaces common to foreign bindings.

Example: connect to the session bus, and get a list of active names.

' &#x7b;-# LANGUAGE OverloadedStrings #-&#x7d;

import Data.List (sort) import DBus import DBus.Client

main = do &#x20; client <- connectSession &#x20; &#x20; -- Request a list of
connected clients from the bus &#x20; reply <- call_ client (methodCall
"/org/freedesktop/DBus" "org.freedesktop.DBus" "ListNames") &#x20; &#x7b;
methodCallDestination = Just "org.freedesktop.DBus" &#x20; &#x7d; &#x20; &#x20;
-- org.freedesktop.DBus.ListNames() returns a single value, which is &#x20; --
a list of names (here represented as [String]) &#x20; let Just names =
fromVariant (methodReturnBody reply !! 0) &#x20; &#x20; -- Print each name on a
line, sorted so reserved names are below &#x20; -- temporary names.
&#x20; mapM_ putStrLn (sort names) '

>$ ghc --make list-names.hs >$ ./list-names >:1.0 >:1.1 >:1.10 >:1.106 >:1.109
>:1.110 >ca.desrt.dconf >org.freedesktop.DBus >org.freedesktop.Notifications
>org.freedesktop.secrets >org.gnome.ScreenSaver.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license license.txt

%files devel -f %{name}-devel.files
%doc examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license license.txt

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Oct 26 2024 Peter Simons <psimons@suse.com>
- Update dbus to version 1.3.9.
  Upstream does not provide a change log file.
* Wed Apr 24 2024 Peter Simons <psimons@suse.com>
- Update dbus to version 1.3.3.
  Upstream does not provide a change log file.
* Tue Dec 26 2023 Peter Simons <psimons@suse.com>
- Update dbus to version 1.3.2.
  Upstream does not provide a change log file.
* Thu Sep 14 2023 Peter Simons <psimons@suse.com>
- Update dbus to version 1.3.1.
  Upstream does not provide a change log file.
* Mon Jun 12 2023 Peter Simons <psimons@suse.com>
- Update dbus to version 1.2.29.
  Upstream does not provide a change log file.
* Mon Apr  3 2023 Peter Simons <psimons@suse.com>
- Update dbus to version 1.2.28.
  Upstream does not provide a change log file.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Oct 24 2022 Peter Simons <psimons@suse.com>
- Update dbus to version 1.2.27.
  Upstream does not provide a change log file.
* Thu Dec 16 2021 Peter Simons <psimons@suse.com>
- Update dbus to version 1.2.22.
  Upstream does not provide a change log file.
* Sun Nov 21 2021 Ondřej Súkup <mimi.vx@gmail.com>
- remove opverspecified constraints on lens
* Sat Feb 27 2021 psimons@suse.com
- Update dbus to version 1.2.21.
  Upstream does not provide a change log file.
* Sun Feb 21 2021 psimons@suse.com
- Update dbus to version 1.2.19.
  Upstream does not provide a change log file.
* Wed Jan 27 2021 psimons@suse.com
- Update dbus to version 1.2.18.
  Upstream does not provide a change log file.
* Tue Dec 29 2020 psimons@suse.com
- Update dbus to version 1.2.17.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sun Jun 28 2020 psimons@suse.com
- Update dbus to version 1.2.16.
  Upstream does not provide a change log file.
* Tue Jun  9 2020 psimons@suse.com
- Update dbus to version 1.2.15.1.
  Upstream does not provide a change log file.
* Wed May  6 2020 psimons@suse.com
- Update dbus to version 1.2.14.
  Upstream does not provide a change log file.
* Fri Feb 28 2020 Peter Simons <psimons@suse.com>
- Update Cabal build information for more accurate dependencies.
* Sun Dec 29 2019 psimons@suse.com
- Update dbus to version 1.2.11.
  Upstream does not provide a change log file.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct 11 2019 Peter Simons <psimons@suse.com>
- Relax overspecified version constraints on lens dependency.
* Mon May 13 2019 psimons@suse.com
- Update dbus to version 1.2.7.
  Upstream does not provide a change log file.
* Tue Apr 30 2019 psimons@suse.com
- Update dbus to version 1.2.6.
  Upstream does not provide a change log file.
* Sun Apr 14 2019 psimons@suse.com
- Update dbus to version 1.2.5.
  Upstream does not provide a change log file.
* Sat Feb 16 2019 psimons@suse.com
- Update dbus to version 1.2.4.
  Upstream does not provide a change log file.
* Tue Jan 22 2019 psimons@suse.com
- Update dbus to version 1.2.3.
  Upstream does not provide a change log file.
* Sun Dec  9 2018 psimons@suse.com
- Update dbus to version 1.2.1.
  Upstream does not provide a change log file.
* Mon Nov 26 2018 psimons@suse.com
- Update dbus to version 1.1.1.
  Upstream does not provide a change log file.
* Sat Nov 24 2018 psimons@suse.com
- Update dbus to version 1.1.0.
  Upstream does not provide a change log file.
* Thu Aug  2 2018 psimons@suse.com
- Add dbus at version 1.0.1.
